<?php

namespace Modules\Parametros\Controllers;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response\Message;
use Zeedhi\Framework\Report\ReportService;
use Zeedhi\Framework\Report\Strategy\BirtStrategy;
use Modules\Parametros\Services\Sup09800MarcasPorFornecedorParaPedidoDeColetaService;

class Sup09800MarcasPorFornecedorParaPedidoDeColetaController extends \Zeedhi\Framework\Controller\Report
{
    protected $qr2Strategy;
    protected $stNomeRel;
    protected $entityManager;
    protected $newCode;
    protected $connection;
    protected $environment;
    protected $birtStrategy;
    protected $reportMapping;
    
	public function __construct($reportService, $qr2Strategy, Sup09800MarcasPorFornecedorParaPedidoDeColetaService $service, $entityManager, $newCode, $connection, $environment, $birtStrategy)
	{
	    $this->reportService = $reportService;
	    $this->qr2Strategy = $qr2Strategy;
	    $this->service = $service;
        $this->entityManager  = $entityManager;
        $this->newCode        = $newCode;
        $this->connection     = $connection;
        $this->environment    = $environment;
        $this->birtStrategy = $birtStrategy;

	}

    public function addMarcaFornecedor(DTO\Request\Row $request, DTO\Response $response)
    {
        $row = $request->getRow();
        if(!empty($row)){
            $this->service->addMarcaFornecedor($row);
        }
    }
    
    public function addCadastramentoAutomatico(DTO\Request\Row $request, DTO\Response $response)
    {
        $row = $request->getRow();
        if(!empty($row)){
            $this->service->addCadastramentoAutomatico($row);   
        }
    }
    
    public function deleteMarcaFornecedor(DTO\Request\Row $request, DTO\Response $response)
    {
        $row = $request->getRow();
        if(!empty($row)){
            $this->service->deleteMarcaFornecedor($row);
        }
    }
    
    public function beforeProcessReport(DTO\Request\Row $request, DTO\Response $response)
    {
        $row = $request->getRow();
        $row['P_NRORG'] = $this->environment->getNrorgTrab();
        $this->initializeReportMapping();
        $this->birtStrategy->setReportFormat(strtolower($row['QR2TYPE']));
        
        if($row['CDFORNECED'] != 'T'){
            $nrlistaForn = $this->criarListaValores($row['CDFORNECED']);
            $row['CDFORNECED'] = "_NRLISTA=".$nrlistaForn;
        } 
        if($row['CDMARCA'] != 'T'){
            $nrlistaMarc = $this->criarListaValores($row['CDMARCA']);
            $row['CDMARCA'] = "_NRLISTA=".$nrlistaMarc;
        }
    }



    public function initializeReportMapping() {
        $params = array (
            'strategy' => 'BIRT',
            'parameterMapping' =>
                array (
                    "CDFORNECED"   => "P_CDFORNECED",
                    "CDMARCA"   => "P_CDMARCA",
                    "P_NRORG"        => "P_NRORG"
                ),
        );
        
        $this->reportMapping = array (
            'SUP09800' => $params,
            'SUP09801' => $params,
        );
    }
    
    protected function criarListaValores($lista){
        $nrlista = $this->newCode->getCodeByTableName('LISTA', $this->environment->getNrOrg());
        $valores = explode('_',$lista);
        try{
            foreach($valores as $key){
                $this->insertLista($nrlista, $key);
            }
            return $nrlista;
        } catch(\Exception $e){
            throw $e;
        }
     }

     public function insertLista($nrlista, $cdlista) {
        $params = array(
            "NRLISTA" => $nrlista,
            "CDLISTA" => $cdlista
        );

        $sql = "INSERT INTO LISTA (NRLISTA, CDLISTA) VALUES (:NRLISTA, :CDLISTA)";
        $query = $this->connection->prepare($sql);
        $query->execute($params);
    }
}
